ToPsk

Trait ToPsk 

pub trait ToPsk {
    // Required method
    fn to_psk(&self, ssid: &Ssid) -> CommonPsk;
}
Conversion of WPA credentials to a PSK.

Required Methods

fn to_psk(&self, ssid: &Ssid) -> CommonPsk

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToPsk for Wpa1Credentials

Conversion of WPA1 credentials to a PSK.

RSN specifies that PSKs are used as-is and passphrases are transformed into a PSK. This implementation performs this transformation when necessary for WPA1 credentials.

Source

fn to_psk(&self, ssid: &Ssid) -> CommonPsk

Source

impl ToPsk for Wpa2PersonalCredentials

Conversion of WPA2 Personal credentials to a PSK.

RSN specifies that PSKs are used as-is and passphrases are transformed into a PSK. This implementation performs this transformation when necessary for WPA2 Personal credentials.

Source

fn to_psk(&self, ssid: &Ssid) -> CommonPsk

Implementors