Struct Igtk Copy item path Source pub struct Igtk {
pub igtk: Vec <u8 >,
pub key_id: u16 ,
pub ipn: [u8 ; 6 ],
pub cipher: Cipher ,
}Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Source  PartialEq implementation explicitly excludes the IPN (Integrity Packet Number).
Both PartialEq and Hash ignore the IPN to prevent key re-installation (KRACK) on retransmissions.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Encodes the object into the encoder’s buffers. Any handles stored in the
object are swapped for
Handle::INVALID.
Read more Encodes the object into the encoder’s buffers. Any handles stored in the
object are swapped for
Handle::INVALID.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more Mutably dereferences the given pointer.
Read more Drops the object pointed to by the given pointer.
Read more The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.